@@ -1477,3 +1477,71 @@ class Image(FunctionNode):
             raise AIEError(AIEErrorCode.ARGS_ERROR, "参数high不能为空")
 
         return FunctionHelper.apply("Image.unitScale", "aie.Image", invoke_args)
+
+    def sinh(self) -> aie.Image:
+
+        invoke_args = {
+            "value": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.sinh", "aie.Image", invoke_args)
+
+    def cosh(self) -> aie.Image:
+
+        invoke_args = {
+            "value": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.cosh", "aie.Image", invoke_args)
+
+    def tanh(self) -> aie.Image:
+
+        invoke_args = {
+            "value": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.tanh", "aie.Image", invoke_args)
+
+    def atan2(self, right: aie.Image) -> aie.Image:
+
+        if right is not None and not isinstance(right, aie.Image):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"right 只支持aie.Image类型参数, 传入类型为{type(right)}"
+            )
+
+        invoke_args = {
+            "left": self,
+            "right": right,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "right" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数right不能为空")
+
+        return FunctionHelper.apply("Image.atan2", "aie.Image", invoke_args)
+
+    def fastAtan2(self, right: aie.Image) -> aie.Image:
+
+        if right is not None and not isinstance(right, aie.Image):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"right 只支持aie.Image类型参数, 传入类型为{type(right)}"
+            )
+
+        invoke_args = {
+            "left": self,
+            "right": right,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "right" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数right不能为空")
+
+        return FunctionHelper.apply("Image.fastAtan2", "aie.Image", invoke_args)
